<?php
/*{@@COPYRIGHT@@}*/
 
defined('VISICHAT_START') or die("Access Denied");

/*
 * Video Chat PayPal class
 *
 */
class PayPal
{
	private $name 		= "PayPal";
	private $options	= array();
	private $testMode	= false;
	private $paymentMethod = NULL;
	private $transactionId = "";
	
	function __construct( $paymentMethod = NULL )
	{
		
		$this->paymentMethod = $paymentMethod;
		$this->options 	 = array();
		$this->options[] = array ("paypal_email" => "Your PayPal Email address");
		$this->transactionId = "";
	}

	//*********************
	// Setters and Getters
	//*********************
	
	/**
	 * Get name of the gateway
	 * 
	 * @return string
	 */ 
	public function getName()
	{
		return $this->name;
	}
	
	/**
	* Get associated payment method
	*
	* @return Payment Method
	*/
	public function getPaymentMethod()
	{
		return $this->paymentMethod;
	}
	
	/**
	* Get options of this gateway
	*
	* @return array
	*/
	public function getOptions()
	{
		return $this->options;
	}
	
	/**
	* Return the transaction id on successful order
	*
	* @return String
	*/
	public function getTransactionId()
	{
		return $this->transactionId;
	}
	
	/**
	* Generate payment form
	*
	* @return string
	*/
	public function getForm( $userId , $referralId )
	{
		$notifyUrl = htmlspecialchars ( VISICHAT_URL . 'scripts/pay.php?g=' . $this->getPaymentMethod()->getId() . '&id=' . $userId. '&referral=' . $referralId .'&ac=verify' );
		$returnUrl = htmlspecialchars ( VISICHAT_URL . 'scripts/pay.php?g=' . $this->getPaymentMethod()->getId() . '&id=' . $userId. '&referral=' . $referralId .'&res=success' );
		$button = "";
		
		if ( $this->testMode )
		{
			$button  = '<form action="https://www.sandbox.paypal.com/cgi-bin/webscr" method="post">';
		}
		else
		{
			$button  = '<form action="https://www.paypal.com/cgi-bin/webscr" method="post">';
		}
		$button .= '<input type="hidden" name="notify_url" value="' . $notifyUrl . '" />';
		$button .= '<input type="hidden" name="business" value="' . $this->getPaymentMethod()->getOption("paypal_email") . '" />';
		$button .= '<input type="hidden" name="bn" value="PP-BuyNowBF" />';
		$button .= '<input type="hidden" name="cmd" value="_xclick" />';
		$button .= '<input type="hidden" name="undefined_quantity" value="0" />';
		$button .= '<input type="hidden" name="amount" value="' . round ( $this->getPaymentMethod()->getPrice() , 2 ) . '" />';
		$button .= '<input type="hidden" name="no_note" value="1" />';
		$button .= '<input type="image" src="' . VISICHAT_URL . 'scripts/api/payment/PayPal/paypal-buynow.gif" name="submit" alt="Make payments with PayPal - its fast, free and secure!" style="border-width:0px; vertical-align:middle;" />';
		$button .= '<input type="hidden" name="return" value="' . $returnUrl . '" />';		  
		$button .= '<input type="hidden" name="rm" value="2" /> ';
		$button .= '<input type="hidden" name="currency_code" value="' . $this->getPaymentMethod()->getCurrency() . '" />';
		$button .= '<input type="hidden" name="item_name" value="' . $this->getPaymentMethod()->getTitle() . '" />';
		$button .= '<input type="hidden" name="item_number" value="' . $userId . '" />';	
		$button .= '</form>';
		
		return $button;
	}
	
	/**
	* Verify if the payment has been sent
	*
	*/
	public function verify()
	{
		
		$this->transactionId = "";
		
		// read the post from PayPal system and add 'cmd'
		$req = 'cmd=_notify-validate';
		
		foreach ($_POST as $key => $value) 
		{
			$value = urlencode ( stripslashes ( $value ) );
			$req .= "&$key=$value";
		}
			
		// assign posted variables to local variables
		$item_name = urldecode ( post('item_name') );
		$item_number = urldecode ( post('item_number') );
		$payment_status = post('payment_status');
		$payment_amount = post('mc_gross');
		$payment_currency = strtolower(post('mc_currency'));
		$txn_id = post('txn_id');
		$receiver_email = urldecode ( post('receiver_email') );
		$payer_email = urldecode ( post('payer_email') );
		$payment_fee = post("mc_fee");
	
		if($payment_amount == "" || !is_numeric($payment_amount))
		{
			$payment_amount = "0";	
		}
		
		if($payment_fee == "" || !is_numeric($payment_fee))
		{
			$payment_fee = "0";	
		}
	  
		$payment_net = $payment_amount-$payment_fee;
		$payer_id = post("payer_id");
		$address = post("address_name")." ".post("address_street")." ".post("address_zip")." ".post("address_state")." ".post("address_city")." ".post("address_country");
		$transaction_subject = post("transaction_subject");
		$memo = post("memo");
	  
		// post back to PayPal system to validate
		$header = "";
		$header .= "POST /cgi-bin/webscr HTTP/1.1\r\n";
		$header .= "Content-Type: application/x-www-form-urlencoded\r\n";
		if ( $this->testMode )
		{
			$header .= "Host: www.sandbox.paypal.com\r\n";
		}
		else
		{
			$header .= "Host: www.paypal.com\r\n";
		}
		$header .= "Content-Length: " . strlen($req) . "\r\n";
		$header .= "Connection: close\r\n\r\n";
		
		if ( $this->testMode )
		{
			$fp = fsockopen ('ssl://www.sandbox.paypal.com', 443, $errno, $errstr, 30);
		}
		else
		{
			$fp = fsockopen ('ssl://www.paypal.com', 443, $errno, $errstr, 30);
		}
  
		if (!$fp) 
		{
			// HTTP ERROR
			return false;
		}
		
		fputs ($fp, $header . $req);
	
		
		while (!feof($fp)) 
		{
	
			$res = fgets ($fp, 1024);
			
						
			if (strcmp (trim($res), 'VERIFIED') == 0)
			{
				
				// check the payment
				if( intval ( $payment_amount ) == intval ( $this->getPaymentMethod()->getPrice() ) && strtolower ( $payment_currency) == strtolower ( $this->getPaymentMethod()->getCurrency() ) && strtolower ( $receiver_email ) == strtolower ( $this->getPaymentMethod()->getOption("paypal_email") ) && $payment_status == "Completed")
				{
					
					$this->transactionId = post('txn_id');
					fclose ($fp);
					return true;	
				}
			}
		}		 
		fclose ($fp);
		
		return false;
	}
}

?>